NetworkLog class

Constructors

NetworkLog({required String id, required String url, required String method, required Map<String, dynamic> requestHeaders, dynamic requestBody, Map<String, dynamic>? responseHeaders, dynamic responseBody, int? statusCode, required DateTime startTime, DateTime? endTime, NetworkStatus status = NetworkStatus.pending})

Properties

displayUrl String
no setter
duration Duration?
no setter
endTime DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
method String
final
requestBody → dynamic
final
requestHeaders Map<String, dynamic>
final
responseBody ↔ dynamic
getter/setter pair
responseHeaders Map<String, dynamic>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime
final
status NetworkStatus
getter/setter pair
statusCode int?
getter/setter pair
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited