DevLensController class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isPanelVisible
→ ValueNotifier<
bool> -
final
-
logs
→ ValueNotifier<
List< DevLog> > -
final
-
networkLogs
→ ValueNotifier<
List< NetworkLog> > -
final
-
routes
→ ValueNotifier<
List< RouteLog> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addNetworkLog(
NetworkLog log) → void -
log(
String message, {LogType type = LogType.info}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
togglePanel(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
trackRoute(
String? name) → void -
updateNetworkLog(
String id, {int? statusCode, dynamic responseBody, Map< String, dynamic> ? responseHeaders, NetworkStatus? status}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → DevLensController
-
final